Class: Yadecli::Cli::Project
- Inherits:
-
Thor
- Object
- Thor
- Yadecli::Cli::Project
- Defined in:
- lib/yadecli/cli/project.rb
Overview
Build
Instance Method Summary collapse
- #install(project_name) ⇒ Object
- #list ⇒ Object
-
#setup(project_name) ⇒ Object
method_option :yes, aliases: ‘-y’, desc: ‘Answering yes to all question, will do a unattended uninstall’.
-
#start(project_name) ⇒ Object
method_option :yes, aliases: ‘-y’, desc: ‘Answering yes to all question, will do a unattended uninstall’.
- #uninstall(project_name) ⇒ Object
Instance Method Details
#install(project_name) ⇒ Object
18 19 20 |
# File 'lib/yadecli/cli/project.rb', line 18 def install(project_name) Yadecli::Service::ProjectService.new.install(project_name, ) end |
#list ⇒ Object
12 13 14 |
# File 'lib/yadecli/cli/project.rb', line 12 def list Yadecli::Service::ProjectService.new.list end |
#setup(project_name) ⇒ Object
method_option :yes, aliases: ‘-y’, desc: ‘Answering yes to all question, will do a unattended uninstall’
30 31 32 |
# File 'lib/yadecli/cli/project.rb', line 30 def setup(project_name) Yadecli::Service::ProjectService.new.setup(project_name, ) end |
#start(project_name) ⇒ Object
method_option :yes, aliases: ‘-y’, desc: ‘Answering yes to all question, will do a unattended uninstall’
36 37 38 |
# File 'lib/yadecli/cli/project.rb', line 36 def start(project_name) Yadecli::Service::ProjectService.new.start(project_name, ) end |
#uninstall(project_name) ⇒ Object
24 25 26 |
# File 'lib/yadecli/cli/project.rb', line 24 def uninstall(project_name) Yadecli::Service::ProjectService.new.uninstall(project_name, ) end |